Segment

Enum Segment 

pub enum Segment {
    LongHand(Vec<Selector>),
    DotName(String),
    Wildcard,
}
Represents the different forms of SPath segment.

Variants



LongHand(Vec<Selector>)

Long hand segments contain multiple selectors inside square brackets.



DotName(String)

Dot-name selectors are a short form for representing keys in an object.



Wildcard

The wildcard shorthand .*.

Implementations

Source

impl Segment

pub fn is_singular(&self) -> bool

Whether this segment extracts at most a singular node.

pub fn as_long_hand(&self) -> Option<&[Selector]>

Optionally produce self as a slice of selectors, from a long hand segment.

pub fn as_dot_name(&self) -> Option<&str>

Optionally produce self as a single name segment.