pub enum Segment {
LongHand(Vec<Selector>),
DotName(String),
Wildcard,
}Expand description
Represents the different forms of SPath segment.
Variants
LongHand(Vec<Selector>)
Long hand segments contain multiple selectors inside square brackets.
DotName(String)
Dot-name selectors are a short form for representing keys in an object.
Wildcard
The wildcard shorthand .*.
Implementations
Sourceimpl Segment
impl Segment
Sourcepub fn is_singular(&self) -> bool
pub fn is_singular(&self) -> bool
Whether this segment extracts at most a singular node.
Sourcepub fn as_long_hand(&self) -> Option<&[Selector]>
pub fn as_long_hand(&self) -> Option<&[Selector]>
Optionally produce self as a slice of selectors, from a long hand segment.
Sourcepub fn as_dot_name(&self) -> Option<&str>
pub fn as_dot_name(&self) -> Option<&str>
Optionally produce self as a single name segment.